==> clutter-1.1.2.tar.gz: clutter-1.1.2/clutter/cogl/cogl/cogl-enum-types.h <==

/* Generated data (by glib-mkenums) */

#ifndef __COGL_ENUM_TYPES_H__
#define __COGL_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "./cogl-debug.h" */
GType cogl_debug_flags_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_DEBUG_FLAGS (cogl_debug_flags_get_type())

/* enumerations from "./cogl-material.h" */
GType cogl_material_filter_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_MATERIAL_FILTER (cogl_material_filter_get_type())

GType cogl_material_alpha_func_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_MATERIAL_ALPHA_FUNC (cogl_material_alpha_func_get_type())

GType cogl_material_layer_type_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_MATERIAL_LAYER_TYPE (cogl_material_layer_type_get_type())

/* enumerations from "./cogl-shader.h" */
GType cogl_shader_type_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_SHADER_TYPE (cogl_shader_type_get_type())

/* enumerations from "./cogl-types.h" */
GType cogl_pixel_format_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_PIXEL_FORMAT (cogl_pixel_format_get_type())

GType cogl_feature_flags_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_FEATURE_FLAGS (cogl_feature_flags_get_type())

GType cogl_buffer_target_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_BUFFER_TARGET (cogl_buffer_target_get_type())

GType cogl_texture_flags_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_TEXTURE_FLAGS (cogl_texture_flags_get_type())

GType cogl_fog_mode_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_FOG_MODE (cogl_fog_mode_get_type())

GType cogl_blend_string_error_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_BLEND_STRING_ERROR (cogl_blend_string_error_get_type())

/* enumerations from "./cogl-vertex-buffer.h" */
GType cogl_attribute_type_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_ATTRIBUTE_TYPE (cogl_attribute_type_get_type())

GType cogl_vertices_mode_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_VERTICES_MODE (cogl_vertices_mode_get_type())

GType cogl_indices_type_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_INDICES_TYPE (cogl_indices_type_get_type())

/* enumerations from "../../../clutter/cogl/cogl/cogl.h" */
GType cogl_buffer_bit_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_BUFFER_BIT (cogl_buffer_bit_get_type())

GType cogl_read_pixels_flags_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_READ_PIXELS_FLAGS (cogl_read_pixels_flags_get_type())

G_END_DECLS

#endif /* !__CLUTTER_ENUM_TYPES_H__ */

/* Generated data ends here */

==> clutter-1.3.6.tar.gz: clutter-1.3.6/clutter/cogl/cogl/cogl-enum-types.h <==

/* Generated data (by glib-mkenums) */

#ifndef __COGL_ENUM_TYPES_H__
#define __COGL_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "./cogl-buffer.h" */
GType cogl_buffer_usage_hint_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_BUFFER_USAGE_HINT (cogl_buffer_usage_hint_get_type())

GType cogl_buffer_update_hint_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_BUFFER_UPDATE_HINT (cogl_buffer_update_hint_get_type())

GType cogl_buffer_access_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_BUFFER_ACCESS (cogl_buffer_access_get_type())

/* enumerations from "./cogl-debug.h" */
GType cogl_debug_flags_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_DEBUG_FLAGS (cogl_debug_flags_get_type())

/* enumerations from "./cogl-material.h" */
GType cogl_material_filter_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_MATERIAL_FILTER (cogl_material_filter_get_type())

GType cogl_material_wrap_mode_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_MATERIAL_WRAP_MODE (cogl_material_wrap_mode_get_type())

GType cogl_material_alpha_func_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_MATERIAL_ALPHA_FUNC (cogl_material_alpha_func_get_type())

GType cogl_material_layer_type_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_MATERIAL_LAYER_TYPE (cogl_material_layer_type_get_type())

GType cogl_depth_test_function_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_DEPTH_TEST_FUNCTION (cogl_depth_test_function_get_type())

/* enumerations from "./cogl-path.h" */
GType cogl_path_fill_rule_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_PATH_FILL_RULE (cogl_path_fill_rule_get_type())

/* enumerations from "./cogl-shader.h" */
GType cogl_shader_type_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_SHADER_TYPE (cogl_shader_type_get_type())

/* enumerations from "./cogl-types.h" */
GType cogl_pixel_format_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_PIXEL_FORMAT (cogl_pixel_format_get_type())

GType cogl_feature_flags_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_FEATURE_FLAGS (cogl_feature_flags_get_type())

GType cogl_buffer_target_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_BUFFER_TARGET (cogl_buffer_target_get_type())

GType cogl_texture_flags_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_TEXTURE_FLAGS (cogl_texture_flags_get_type())

GType cogl_fog_mode_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_FOG_MODE (cogl_fog_mode_get_type())

GType cogl_blend_string_error_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_BLEND_STRING_ERROR (cogl_blend_string_error_get_type())

GType cogl_error_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_ERROR (cogl_error_get_type())

/* enumerations from "./cogl-vertex-buffer.h" */
GType cogl_attribute_type_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_ATTRIBUTE_TYPE (cogl_attribute_type_get_type())

GType cogl_vertices_mode_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_VERTICES_MODE (cogl_vertices_mode_get_type())

GType cogl_indices_type_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_INDICES_TYPE (cogl_indices_type_get_type())

/* enumerations from "./cogl.h" */
GType cogl_buffer_bit_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_BUFFER_BIT (cogl_buffer_bit_get_type())

GType cogl_read_pixels_flags_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_READ_PIXELS_FLAGS (cogl_read_pixels_flags_get_type())

GType cogl_driver_error_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_DRIVER_ERROR (cogl_driver_error_get_type())

/* enumerations from "./winsys/cogl-texture-pixmap-x11.h" */
GType cogl_texture_pixmap_x11_report_level_get_type (void) G_GNUC_CONST;
#define COGL_TYPE_TEXTURE_PIXMAP_X11_REPORT_LEVEL (cogl_texture_pixmap_x11_report_level_get_type())

G_END_DECLS

#endif /* !__CLUTTER_ENUM_TYPES_H__ */

/* Generated data ends here */
